# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables


class CacheNfsTarget(pulumi.CustomResource):
    cache_name: pulumi.Output[str]
    """
    The name HPC Cache, which the HPC Cache NFS Target will be added to. Changing this forces a new resource to be created.
    """
    name: pulumi.Output[str]
    """
    The name of the HPC Cache NFS Target. Changing this forces a new resource to be created.
    """
    namespace_junctions: pulumi.Output[list]
    """
    Can be specified multiple times to define multiple `namespace_junction`. Each `namespace_juntion` block supports fields documented below.

      * `namespace_path` (`str`) - The client-facing file path of this NFS target within the HPC Cache NFS Target.
      * `nfsExport` (`str`) - The NFS export of this NFS target within the HPC Cache NFS Target.
      * `targetPath` (`str`) - The relative subdirectory path from the `nfs_export` to map to the `namespace_path`. Defaults to `""`, in which case the whole `nfs_export` is exported.
    """
    resource_group_name: pulumi.Output[str]
    """
    The name of the Resource Group in which to create the HPC Cache NFS Target. Changing this forces a new resource to be created.
    """
    target_host_name: pulumi.Output[str]
    """
    The IP address or fully qualified domain name (FQDN) of the HPC Cache NFS target. Changing this forces a new resource to be created.
    """
    usage_model: pulumi.Output[str]
    """
    The type of usage of the HPC Cache NFS Target.
    """
    def __init__(__self__, resource_name, opts=None, cache_name=None, name=None, namespace_junctions=None, resource_group_name=None, target_host_name=None, usage_model=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages a NFS Target within a HPC Cache.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cache_name: The name HPC Cache, which the HPC Cache NFS Target will be added to. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the HPC Cache NFS Target. Changing this forces a new resource to be created.
        :param pulumi.Input[list] namespace_junctions: Can be specified multiple times to define multiple `namespace_junction`. Each `namespace_juntion` block supports fields documented below.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group in which to create the HPC Cache NFS Target. Changing this forces a new resource to be created.
        :param pulumi.Input[str] target_host_name: The IP address or fully qualified domain name (FQDN) of the HPC Cache NFS target. Changing this forces a new resource to be created.
        :param pulumi.Input[str] usage_model: The type of usage of the HPC Cache NFS Target.

        The **namespace_junctions** object supports the following:

          * `namespace_path` (`pulumi.Input[str]`) - The client-facing file path of this NFS target within the HPC Cache NFS Target.
          * `nfsExport` (`pulumi.Input[str]`) - The NFS export of this NFS target within the HPC Cache NFS Target.
          * `targetPath` (`pulumi.Input[str]`) - The relative subdirectory path from the `nfs_export` to map to the `namespace_path`. Defaults to `""`, in which case the whole `nfs_export` is exported.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if cache_name is None:
                raise TypeError("Missing required property 'cache_name'")
            __props__['cache_name'] = cache_name
            __props__['name'] = name
            if namespace_junctions is None:
                raise TypeError("Missing required property 'namespace_junctions'")
            __props__['namespace_junctions'] = namespace_junctions
            if resource_group_name is None:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__['resource_group_name'] = resource_group_name
            if target_host_name is None:
                raise TypeError("Missing required property 'target_host_name'")
            __props__['target_host_name'] = target_host_name
            if usage_model is None:
                raise TypeError("Missing required property 'usage_model'")
            __props__['usage_model'] = usage_model
        super(CacheNfsTarget, __self__).__init__(
            'azure:hpc/cacheNfsTarget:CacheNfsTarget',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, cache_name=None, name=None, namespace_junctions=None, resource_group_name=None, target_host_name=None, usage_model=None):
        """
        Get an existing CacheNfsTarget resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cache_name: The name HPC Cache, which the HPC Cache NFS Target will be added to. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the HPC Cache NFS Target. Changing this forces a new resource to be created.
        :param pulumi.Input[list] namespace_junctions: Can be specified multiple times to define multiple `namespace_junction`. Each `namespace_juntion` block supports fields documented below.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group in which to create the HPC Cache NFS Target. Changing this forces a new resource to be created.
        :param pulumi.Input[str] target_host_name: The IP address or fully qualified domain name (FQDN) of the HPC Cache NFS target. Changing this forces a new resource to be created.
        :param pulumi.Input[str] usage_model: The type of usage of the HPC Cache NFS Target.

        The **namespace_junctions** object supports the following:

          * `namespace_path` (`pulumi.Input[str]`) - The client-facing file path of this NFS target within the HPC Cache NFS Target.
          * `nfsExport` (`pulumi.Input[str]`) - The NFS export of this NFS target within the HPC Cache NFS Target.
          * `targetPath` (`pulumi.Input[str]`) - The relative subdirectory path from the `nfs_export` to map to the `namespace_path`. Defaults to `""`, in which case the whole `nfs_export` is exported.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["cache_name"] = cache_name
        __props__["name"] = name
        __props__["namespace_junctions"] = namespace_junctions
        __props__["resource_group_name"] = resource_group_name
        __props__["target_host_name"] = target_host_name
        __props__["usage_model"] = usage_model
        return CacheNfsTarget(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop
