# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

# Export this package's modules as members:
from .a_record import *
from .aaaa_record import *
from .cname_record import *
from .get_dns_zone import *
from .link_service import *
from .mx_record import *
from .ptr_record import *
from .srv_record import *
from .txt_record import *
from .zone import *
from .zone_virtual_network_link import *
