# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import importlib
# Export this package's modules as members:
from .provider import *

# Make subpackages available:
_submodules = [
    'advisor',
    'analysisservices',
    'apimanagement',
    'appconfiguration',
    'appinsights',
    'appplatform',
    'appservice',
    'authorization',
    'automation',
    'backup',
    'batch',
    'blueprint',
    'bot',
    'cdn',
    'cognitive',
    'compute',
    'config',
    'containerservice',
    'core',
    'cosmosdb',
    'costmanagement',
    'dashboard',
    'databasemigration',
    'databricks',
    'datafactory',
    'datalake',
    'datashare',
    'devspace',
    'devtest',
    'dns',
    'eventgrid',
    'eventhub',
    'frontdoor',
    'hdinsight',
    'healthcare',
    'hpc',
    'iot',
    'iotcentral',
    'keyvault',
    'kusto',
    'lb',
    'loganalytics',
    'logicapps',
    'machinelearning',
    'maintenance',
    'managedapplication',
    'management',
    'managementgroups',
    'managementresource',
    'maps',
    'mariadb',
    'marketplace',
    'mediaservices',
    'mixedreality',
    'monitoring',
    'msi',
    'mssql',
    'mysql',
    'netapp',
    'network',
    'notificationhub',
    'operationalinsights',
    'policy',
    'postgresql',
    'powerbi',
    'privatedns',
    'privatelink',
    'proximity',
    'recoveryservices',
    'redis',
    'relay',
    'role',
    'search',
    'securitycenter',
    'sentinel',
    'servicebus',
    'servicefabric',
    'signalr',
    'siterecovery',
    'sql',
    'storage',
    'streamanalytics',
    'trafficmanager',
    'waf',
]
for pkg in _submodules:
    if pkg != 'config':
        importlib.import_module(f'{__name__}.{pkg}')
