# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetAppServiceEnvironmentResult:
    """
    A collection of values returned by getAppServiceEnvironment.
    """
    def __init__(__self__, front_end_scale_factor=None, id=None, location=None, name=None, pricing_tier=None, resource_group_name=None, tags=None):
        if front_end_scale_factor and not isinstance(front_end_scale_factor, float):
            raise TypeError("Expected argument 'front_end_scale_factor' to be a float")
        __self__.front_end_scale_factor = front_end_scale_factor
        """
        The number of app instances per App Service Environment Front End
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if location and not isinstance(location, str):
            raise TypeError("Expected argument 'location' to be a str")
        __self__.location = location
        """
        The Azure location where the App Service Environment exists
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        if pricing_tier and not isinstance(pricing_tier, str):
            raise TypeError("Expected argument 'pricing_tier' to be a str")
        __self__.pricing_tier = pricing_tier
        """
        The Pricing Tier (Isolated SKU) of the App Service Environment.
        """
        if resource_group_name and not isinstance(resource_group_name, str):
            raise TypeError("Expected argument 'resource_group_name' to be a str")
        __self__.resource_group_name = resource_group_name
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        __self__.tags = tags
        """
        A mapping of tags assigned to the resource.
        """
class AwaitableGetAppServiceEnvironmentResult(GetAppServiceEnvironmentResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAppServiceEnvironmentResult(
            front_end_scale_factor=self.front_end_scale_factor,
            id=self.id,
            location=self.location,
            name=self.name,
            pricing_tier=self.pricing_tier,
            resource_group_name=self.resource_group_name,
            tags=self.tags)

def get_app_service_environment(name=None,resource_group_name=None,opts=None):
    """
    Use this data source to access information about an existing App Service Environment

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.appservice.get_app_service_environment(name="example-ase",
        resource_group_name="example-rg")
    pulumi.export("appServiceEnvironmentId", data["azurerm_app_service_environment"]["id"])
    ```


    :param str name: The name of the App Service Environment.
    :param str resource_group_name: The Name of the Resource Group where the App Service Environment exists.
    """
    __args__ = dict()


    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('azure:appservice/getAppServiceEnvironment:getAppServiceEnvironment', __args__, opts=opts).value

    return AwaitableGetAppServiceEnvironmentResult(
        front_end_scale_factor=__ret__.get('frontEndScaleFactor'),
        id=__ret__.get('id'),
        location=__ret__.get('location'),
        name=__ret__.get('name'),
        pricing_tier=__ret__.get('pricingTier'),
        resource_group_name=__ret__.get('resourceGroupName'),
        tags=__ret__.get('tags'))
