# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables


class NetworkConnectionMonitor(pulumi.CustomResource):
    auto_start: pulumi.Output[bool]
    """
    Specifies whether the connection monitor will start automatically once created. Defaults to `true`. Changing this forces a new resource to be created.
    """
    destination: pulumi.Output[dict]
    """
    A `destination` block as defined below.

      * `address` (`str`) - IP address or domain name to monitor connectivity to.
      * `port` (`float`) - The port on the destination to monitor connectivity to.
      * `virtual_machine_id` (`str`) - The ID of the Virtual Machine to monitor connectivity to.
    """
    interval_in_seconds: pulumi.Output[float]
    """
    Monitoring interval in seconds. Defaults to `60`.
    """
    location: pulumi.Output[str]
    """
    Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
    """
    name: pulumi.Output[str]
    """
    The name of the Network Connection Monitor. Changing this forces a new resource to be created.
    """
    network_watcher_name: pulumi.Output[str]
    """
    The name of the Network Watcher. Changing this forces a new resource to be created.
    """
    resource_group_name: pulumi.Output[str]
    """
    The name of the resource group in which to create the Connection Monitor. Changing this forces a new resource to be created.
    """
    source: pulumi.Output[dict]
    """
    A `source` block as defined below.

      * `port` (`float`) - The port on the destination to monitor connectivity to.
      * `virtual_machine_id` (`str`) - The ID of the Virtual Machine to monitor connectivity to.
    """
    tags: pulumi.Output[dict]
    """
    A mapping of tags to assign to the resource.
    """
    def __init__(__self__, resource_name, opts=None, auto_start=None, destination=None, interval_in_seconds=None, location=None, name=None, network_watcher_name=None, resource_group_name=None, source=None, tags=None, __props__=None, __name__=None, __opts__=None):
        """
        Configures a Network Connection Monitor to monitor communication between a Virtual Machine and an endpoint using a Network Watcher.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example_resource_group = azure.core.ResourceGroup("exampleResourceGroup", location="West US")
        example_network_watcher = azure.network.NetworkWatcher("exampleNetworkWatcher",
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name)
        example_virtual_network = azure.network.VirtualNetwork("exampleVirtualNetwork",
            address_spaces=["10.0.0.0/16"],
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name)
        example_subnet = azure.network.Subnet("exampleSubnet",
            resource_group_name=example_resource_group.name,
            virtual_network_name=example_virtual_network.name,
            address_prefix="10.0.2.0/24")
        example_network_interface = azure.network.NetworkInterface("exampleNetworkInterface",
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name,
            ip_configurations=[{
                "name": "testconfiguration1",
                "subnet_id": example_subnet.id,
                "privateIpAddressAllocation": "Dynamic",
            }])
        example_virtual_machine = azure.compute.VirtualMachine("exampleVirtualMachine",
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name,
            network_interface_ids=[example_network_interface.id],
            vm_size="Standard_F2",
            storage_image_reference={
                "publisher": "Canonical",
                "offer": "UbuntuServer",
                "sku": "16.04-LTS",
                "version": "latest",
            },
            storage_os_disk={
                "name": "osdisk",
                "caching": "ReadWrite",
                "create_option": "FromImage",
                "managedDiskType": "Standard_LRS",
            },
            os_profile={
                "computer_name": "cmtest-vm",
                "admin_username": "testadmin",
                "admin_password": "Password1234!",
            },
            os_profile_linux_config={
                "disable_password_authentication": False,
            })
        example_extension = azure.compute.Extension("exampleExtension",
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name,
            virtual_machine_name=example_virtual_machine.name,
            publisher="Microsoft.Azure.NetworkWatcher",
            type="NetworkWatcherAgentLinux",
            type_handler_version="1.4",
            auto_upgrade_minor_version=True)
        example_network_connection_monitor = azure.network.NetworkConnectionMonitor("exampleNetworkConnectionMonitor",
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name,
            network_watcher_name=example_network_watcher.name,
            source={
                "virtual_machine_id": example_virtual_machine.id,
            },
            destination={
                "address": "exmaple.com",
                "port": 80,
            },
            opts=ResourceOptions(depends_on=[example_extension]))
        ```

        > **NOTE:** This Resource requires that [the Network Watcher Agent Virtual Machine Extension](https://docs.microsoft.com/en-us/azure/network-watcher/connection-monitor) is installed on the Virtual Machine before monitoring can be started. The extension can be installed via the `compute.Extension` resource.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] auto_start: Specifies whether the connection monitor will start automatically once created. Defaults to `true`. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] destination: A `destination` block as defined below.
        :param pulumi.Input[float] interval_in_seconds: Monitoring interval in seconds. Defaults to `60`.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the Network Connection Monitor. Changing this forces a new resource to be created.
        :param pulumi.Input[str] network_watcher_name: The name of the Network Watcher. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which to create the Connection Monitor. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] source: A `source` block as defined below.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.

        The **destination** object supports the following:

          * `address` (`pulumi.Input[str]`) - IP address or domain name to monitor connectivity to.
          * `port` (`pulumi.Input[float]`) - The port on the destination to monitor connectivity to.
          * `virtual_machine_id` (`pulumi.Input[str]`) - The ID of the Virtual Machine to monitor connectivity to.

        The **source** object supports the following:

          * `port` (`pulumi.Input[float]`) - The port on the destination to monitor connectivity to.
          * `virtual_machine_id` (`pulumi.Input[str]`) - The ID of the Virtual Machine to monitor connectivity to.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['auto_start'] = auto_start
            if destination is None:
                raise TypeError("Missing required property 'destination'")
            __props__['destination'] = destination
            __props__['interval_in_seconds'] = interval_in_seconds
            __props__['location'] = location
            __props__['name'] = name
            if network_watcher_name is None:
                raise TypeError("Missing required property 'network_watcher_name'")
            __props__['network_watcher_name'] = network_watcher_name
            if resource_group_name is None:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__['resource_group_name'] = resource_group_name
            if source is None:
                raise TypeError("Missing required property 'source'")
            __props__['source'] = source
            __props__['tags'] = tags
        super(NetworkConnectionMonitor, __self__).__init__(
            'azure:network/networkConnectionMonitor:NetworkConnectionMonitor',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, auto_start=None, destination=None, interval_in_seconds=None, location=None, name=None, network_watcher_name=None, resource_group_name=None, source=None, tags=None):
        """
        Get an existing NetworkConnectionMonitor resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] auto_start: Specifies whether the connection monitor will start automatically once created. Defaults to `true`. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] destination: A `destination` block as defined below.
        :param pulumi.Input[float] interval_in_seconds: Monitoring interval in seconds. Defaults to `60`.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the Network Connection Monitor. Changing this forces a new resource to be created.
        :param pulumi.Input[str] network_watcher_name: The name of the Network Watcher. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which to create the Connection Monitor. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] source: A `source` block as defined below.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.

        The **destination** object supports the following:

          * `address` (`pulumi.Input[str]`) - IP address or domain name to monitor connectivity to.
          * `port` (`pulumi.Input[float]`) - The port on the destination to monitor connectivity to.
          * `virtual_machine_id` (`pulumi.Input[str]`) - The ID of the Virtual Machine to monitor connectivity to.

        The **source** object supports the following:

          * `port` (`pulumi.Input[float]`) - The port on the destination to monitor connectivity to.
          * `virtual_machine_id` (`pulumi.Input[str]`) - The ID of the Virtual Machine to monitor connectivity to.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["auto_start"] = auto_start
        __props__["destination"] = destination
        __props__["interval_in_seconds"] = interval_in_seconds
        __props__["location"] = location
        __props__["name"] = name
        __props__["network_watcher_name"] = network_watcher_name
        __props__["resource_group_name"] = resource_group_name
        __props__["source"] = source
        __props__["tags"] = tags
        return NetworkConnectionMonitor(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop
