# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

# Export this package's modules as members:
from .availability_set import *
from .bastion_host import *
from .data_disk_attachment import *
from .dedicated_host import *
from .dedicated_host_group import *
from .disk_encryption_set import *
from .extension import *
from .get_availability_set import *
from .get_dedicated_host import *
from .get_dedicated_host_group import *
from .get_disk_encryption_set import *
from .get_image import *
from .get_managed_disk import *
from .get_platform_image import *
from .get_shared_image import *
from .get_shared_image_gallery import *
from .get_shared_image_version import *
from .get_shared_image_versions import *
from .get_snapshot import *
from .get_virtual_machine import *
from .get_virtual_machine_scale_set import *
from .image import *
from .linux_virtual_machine import *
from .linux_virtual_machine_scale_set import *
from .managed_disk import *
from .orchestrated_virtual_machine_scale_set import *
from .scale_set import *
from .shared_image import *
from .shared_image_gallery import *
from .shared_image_version import *
from .snapshot import *
from .virtual_machine import *
from .virtual_machine_scale_set_extension import *
from .windows_virtual_machine import *
from .windows_virtual_machine_scale_set import *
