# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

# Export this package's modules as members:
from .get_lab import *
from .get_virtual_network import *
from .global_vm_shutdown_schedule import *
from .lab import *
from .linux_virtual_machine import *
from .policy import *
from .schedule import *
from .virtual_network import *
from .windows_virtual_machine import *
